@@ -11,15 +11,12 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import List
+from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
-
-import sys
-
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -29,6 +26,7 @@ else:
 __all__ = (
     "HumanLoopOutputTypeDef",
     "HumanLoopSummaryTypeDef",
+    "ResponseMetadata",
     "DescribeHumanLoopResponseTypeDef",
     "HumanLoopDataAttributesTypeDef",
     "HumanLoopInputTypeDef",
@@ -37,7 +35,15 @@ __all__ = (
     "StartHumanLoopResponseTypeDef",
 )
 
-HumanLoopOutputTypeDef = TypedDict("HumanLoopOutputTypeDef", {"OutputS3Uri": str})
+_RequiredHumanLoopOutputTypeDef = TypedDict("_RequiredHumanLoopOutputTypeDef", {"OutputS3Uri": str})
+_OptionalHumanLoopOutputTypeDef = TypedDict(
+    "_OptionalHumanLoopOutputTypeDef", {"ResponseMetadata": "ResponseMetadata"}, total=False
+)
+
+
+class HumanLoopOutputTypeDef(_RequiredHumanLoopOutputTypeDef, _OptionalHumanLoopOutputTypeDef):
+    pass
+
 
 HumanLoopSummaryTypeDef = TypedDict(
     "HumanLoopSummaryTypeDef",
@@ -51,6 +57,17 @@ HumanLoopSummaryTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadata = TypedDict(
+    "ResponseMetadata",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 _RequiredDescribeHumanLoopResponseTypeDef = TypedDict(
     "_RequiredDescribeHumanLoopResponseTypeDef",
     {
